What’s new in version 1.2.5
===========================
Version available since March 19th 2023


New Features
------------

- New file "ode45_fft" to compute ODE systems and their FFT.
- New file "ode45_extract_fft" to compute ODE systems, their FFT and to extract parameters from simulations.

Bug fixed
---------



Contributors
------------
Lucas Agobert
